==> admin-mongo-0.0.8.tgz: package/locales/en.js <==
{
	"Connections": "Connections",
	"Database": "Database",
	"Not selected": "Not selected",
	"Collection": "Collection",
	"Database Objects": "Database Objects",
	"Edit Collection name": "Edit Collection name",
	"Close": "Close",
	"Save changes": "Save changes",
	"Search for documents": "Search for documents",
	"BSON types are not supported": "BSON types are not supported",
	"Key (Field)": "Key (Field)",
	"Value": "Value",
	"Search": "Search",
	"Query documents": "Query documents",
	"Queries need to be BSON types or Extended JSON formatted": "Queries need to be BSON types or Extended JSON formatted",
	"Send query": "Send query",
	"Export collection": "Export collection",
	"Exclude": "Exclude",
	"field": "field",
	"Export": "Export",
	"Connection name": "Connection name",
	"Connection string": "Connection string",
	"Action": "Action",
	"Delete": "Delete",
	"Update": "Update",
	"A name for connection": "A name for connection",
	"Add connection": "Add connection",
	"Connect": "Connect",
	"Database maintenance": "Database maintenance",
	"Create new database": "Create new database",
	"Create": "Create",
	"Delete database": "Delete database",
	"Connection statistics": "Connection statistics",
	"Storage": "Storage",
	"Documents": "Documents",
	"Home": "Home",
	"connection": "connection",
	"database": "database",
	"collection": "collection",
	"Back": "Back",
	"Add index": "Add index",
	"Options": "Options",
	"Unique": "Unique",
	"Sparse": "Sparse",
	"Name": "Name",
	"Key": "Key",
	"Delete index": "Delete index",
	"Collection maintenance": "Collection maintenance",
	"Delete collection": "Delete collection",
	"Create User": "Create User",
	"Username": "Username",
	"User Password": "User Password",
	"Confirm password": "Confirm password",
	"Roles": "Roles",
	"Create user": "Create user",
	"Delete user": "Delete user",
	"Database statistics": "Database statistics",
	"New document": "New document",
	"Simple search": "Simple search",
	"Reset": "Reset",
	"Manage indexes": "Manage indexes",
	"Finding docs": "Finding docs",
	"No documents found": "No documents found",
	"Save document": "Save document",
	"database name": "database name",
	"Please enter password": "Please enter password",
	"Password": "Password",
	"Sign in": "Sign in",
	"Logout": "Logout",
	"Config successfully added": "Config successfully added",
	"collection Name": "collection Name",
	"Confirm": "Confirm",
	"Optional: comma separated user roles": "Optional: comma separated user roles",
	"Invalid connection name": "Invalid connection name",
	"Add document": "Add document",
	"Config successfully updated": "Config successfully updated",
	"User successfully created": "User successfully created",
	"Error deleting user": "Error deleting user",
	"User successfully deleted": "User successfully deleted",
	"Error renaming collection": "Error renaming collection",
	"Collection successfully renamed": "Collection successfully renamed",
	"Error creating user": "Error creating user",
	"Index successfully created": "Index successfully created",
	"Index successfully dropped": "Index successfully dropped",
	"Error creating index": "Error creating index",
	"Document successfully added": "Document successfully added",
	"Collection successfully created": "Collection successfully created",
	"Collection successfully deleted": "Collection successfully deleted",
	"Database successfully created": "Database successfully created",
	"Database successfully deleted": "Database successfully deleted",
	"Syntax error. Please check the syntax": "Syntax error. Please check the syntax",
	"Document successfully updated": "Document successfully updated",
	"Document successfully deleted": "Document successfully deleted",
	"Config successfully deleted": "Config successfully deleted",
	"Config error": "Config error",
	"Config error: A connection by that name already exists": "Config error: A connection by that name already exists",
	"Error dropping Index": "Error dropping Index",
	"Error deleting collection": "Error deleting collection",
	"Edit": "Edit",
	"Total records": "Total records",
	"Invalid connection": "Invalid connection",
	"Cannot find document by Id": "Cannot find document by Id"
}

==> admin-mongo-0.0.9.tgz: package/locales/en.js <==
{
	"Connections": "Connections",
	"Database": "Database",
	"Not selected": "Not selected",
	"Collection": "Collection",
	"Database Objects": "Database Objects",
	"Edit Collection name": "Edit Collection name",
	"Close": "Close",
	"Save changes": "Save changes",
	"Search for documents": "Search for documents",
	"BSON types are not supported": "BSON types are not supported",
	"Key (Field)": "Key (Field)",
	"Value": "Value",
	"Search": "Search",
	"Query documents": "Query documents",
	"Queries need to be BSON types or Extended JSON formatted": "Queries need to be BSON types or Extended JSON formatted",
	"Send query": "Send query",
	"Export collection": "Export collection",
	"Exclude": "Exclude",
	"field": "field",
	"Export": "Export",
	"Connection name": "Connection name",
	"Connection string": "Connection string",
	"Action": "Action",
	"Delete": "Delete",
	"Update": "Update",
	"A name for connection": "A name for connection",
	"Add connection": "Add connection",
	"Connect": "Connect",
	"Database maintenance": "Database maintenance",
	"Create new database": "Create new database",
	"Create": "Create",
	"Delete database": "Delete database",
	"Connection statistics": "Connection statistics",
	"Storage": "Storage",
	"Documents": "Documents",
	"Home": "Home",
	"connection": "connection",
	"database": "database",
	"collection": "collection",
	"Back": "Back",
	"Add index": "Add index",
	"Options": "Options",
	"Unique": "Unique",
	"Sparse": "Sparse",
	"Name": "Name",
	"Key": "Key",
	"Delete index": "Delete index",
	"Collection maintenance": "Collection maintenance",
	"Delete collection": "Delete collection",
	"Create User": "Create User",
	"Username": "Username",
	"User Password": "User Password",
	"Confirm password": "Confirm password",
	"Roles": "Roles",
	"Create user": "Create user",
	"Delete user": "Delete user",
	"Database statistics": "Database statistics",
	"New document": "New document",
	"Simple search": "Simple search",
	"Reset": "Reset",
	"Manage indexes": "Manage indexes",
	"Finding docs": "Finding docs",
	"No documents found": "No documents found",
	"Save document": "Save document",
	"database name": "database name",
	"Please enter password": "Please enter password",
	"Password": "Password",
	"Sign in": "Sign in",
	"Logout": "Logout",
	"Config successfully added": "Config successfully added",
	"collection Name": "collection Name",
	"Confirm": "Confirm",
	"Optional: comma separated user roles": "Optional: comma separated user roles",
	"Invalid connection name": "Invalid connection name",
	"Add document": "Add document",
	"Config successfully updated": "Config successfully updated",
	"User successfully created": "User successfully created",
	"Error deleting user": "Error deleting user",
	"User successfully deleted": "User successfully deleted",
	"Error renaming collection": "Error renaming collection",
	"Collection successfully renamed": "Collection successfully renamed",
	"Error creating user": "Error creating user",
	"Index successfully created": "Index successfully created",
	"Index successfully dropped": "Index successfully dropped",
	"Error creating index": "Error creating index",
	"Document successfully added": "Document successfully added",
	"Collection successfully created": "Collection successfully created",
	"Collection successfully deleted": "Collection successfully deleted",
	"Database successfully created": "Database successfully created",
	"Database successfully deleted": "Database successfully deleted",
	"Syntax error. Please check the syntax": "Syntax error. Please check the syntax",
	"Document successfully updated": "Document successfully updated",
	"Document successfully deleted": "Document successfully deleted",
	"Config successfully deleted": "Config successfully deleted",
	"Config error": "Config error",
	"Config error: A connection by that name already exists": "Config error: A connection by that name already exists",
	"Error dropping Index": "Error dropping Index",
	"Error deleting collection": "Error deleting collection",
	"Edit": "Edit",
	"Total records": "Total records",
	"Invalid connection": "Invalid connection",
	"Cannot find document by Id": "Cannot find document by Id",
	"Document not found": "Document not found",
	"Create collection": "Create collection"
}
